Welcome to Advection's documentation!
======================================

A lightweight Python toolkit for diagnosing **horizontal and vertical
advection** and correcting the **energy-balance closure gap** in
30-minute eddy-covariance data from Campbell Scientific *IRGASON* and
similar open-path systems.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   quickstart
   usage
   modules
   contributing
   authors
   history

.. toctree::
   :maxdepth: 2
   :caption: Guides

   guides/energy_balance_closure

.. toctree::
   :maxdepth: 1
   :caption: API Reference

   reference/advect_detect
   reference/advection

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
